@@ -12,13 +12,13 @@ THREAD_TIMEOUT = 100000
 def start_tail(args):
   if args.requestId:
     sys.stderr.write('Fetching tasks\n')
-    tasks = [str(t) for t in logfetch_base.tasks_for_request(args)]
+    tasks = [str(t) for t in logfetch_base.tasks_for_requests(args)]
   else:
     tasks = [args.taskId]
   if args.verbose:
     sys.stderr.write(colored('Tailing logs for tasks:\n', 'green'))
     for t in tasks:
-      sys.stderr.write(colored('{0}\n'.format(t), 'blue'))
+      sys.stderr.write(colored('{0}\n'.format(t), 'yellow'))
   sys.stderr.write(colored('ctrl+c to exit\n', 'cyan'))
   try:
     threads = []
@@ -31,7 +31,7 @@ def start_tail(args):
       if not t.isAlive:
         break
   except KeyboardInterrupt:
-    sys.stderr.write(colored('Stopping tail', 'cyan'))
+    sys.stderr.write(colored('Stopping tail', 'magenta'))
     sys.exit(0)
 
 class LogStreamer(threading.Thread):
@@ -73,6 +73,7 @@ class LogStreamer(threading.Thread):
     if args.grep:
       params['grep'] = args.grep
     response = requests.get(uri, params=params).json()
-    prefix = '({0}) =>'.format(task) if args.verbose else ''
-    sys.stdout.write('{0}{1}\n'.format(colored(prefix, 'blue'), response['data']))
+    prefix = '({0}) =>\n'.format(task) if args.verbose else ''
+    if response['data'] != '':
+        sys.stdout.write('{0}{1}'.format(colored(prefix, 'cyan'), response['data']))
     return offset + len(response['data'].encode('utf-8'))
